# Generated by Django 3.2.5 on 2021-07-27 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0024_alter_assessment_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='assessment',
            name='open_to_start',
            field=models.BooleanField(default=False),
        ),
    ]
