# Generated by Django 3.2.5 on 2021-07-25 11:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0021_alter_candidateassessment_assessment'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='job',
            name='assessment',
        ),
        migrations.AddField(
            model_name='job',
            name='assessments',
            field=models.ManyToManyField(to='job_board.Assessment'),
        ),
    ]
