# Generated by Django 3.2.5 on 2021-07-14 10:37

from django.db import migrations, models
import job_board.models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0006_auto_20210714_1333'),
    ]

    operations = [
        migrations.AddField(
            model_name='candidatejob',
            name='additional_message',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='candidatejob',
            name='expected_salary',
            field=models.FloatField(default=0.0),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='candidate',
            name='cv',
            field=models.FileField(upload_to=job_board.models.candidate_email_path),
        ),
    ]
