# Generated by Django 3.2.5 on 2021-07-28 13:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0027_auto_20210728_1546'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='assessment',
            name='score',
        ),
    ]
