# Generated by Django 3.2.5 on 2021-07-25 10:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0020_remove_candidateassessment_exam_type'),
    ]

    operations = [
        migrations.AlterField(
            model_name='candidateassessment',
            name='assessment',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='job_board.assessment'),
            preserve_default=False,
        ),
    ]
