<!doctype html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Job Board - Powered By Mediusware</title>
    <!-- CSS only -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css" rel="stylesheet"
          integrity="sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC" crossorigin="anonymous">
</head>
<body>
<div class="container p-5">
    <h1>Currently we are working on job board front end part</h1>
    <p>You can still use the job board APIs with you any favorite front end library such as Vuejs or React Js</p>
    <hr>
    <h3>Api end points</h3>
    <hr>
    <h4>Auth</h4>
    <p><a href="{% url 'jb_login' %}">{% url 'jb_login' %}</a></p>
    <p><a href="{% url 'jb_registration' %}">{% url 'jb_registration' %}</a></p>
    <p><a href="{% url 'jb_candidate' %}">{% url 'jb_candidate' %}</a></p>
    <p><a href="{% url 'jb_send_otp' %}">{% url 'jb_send_otp' %}</a></p>
    <p><a href="{% url 'jb_reset_password' %}">{% url 'jb_reset_password' %}</a></p>
    <h4>Jobs</h4>
    <p><a href="{% url 'jb_jobs' %}">{% url 'jb_jobs' %}</a></p>
    <p><a href="{% url 'jb_job' 'asdfasfdadf' %}">{% url 'jb_job' 'asdfasfdadf' %}</a></p>
    <h4>Job Apply</h4>
    <p><a href="{% url 'jb_job_apply' %}">{% url 'jb_job_apply' %}</a></p>
    <h4>Assessments</h4>
    <p><a href="{% url 'jb_assessments' %}">{% url 'jb_assessments' %}</a></p>
    <p>
        <a href="{% url 'jb_assessment' '123e4567-e89b-12d3-a456-426614174000' %}">
            {% url 'jb_assessment' '123e4567-e89b-12d3-a456-426614174000' %}
        </a>
    </p>
    <p>
        <a href="{% url 'fetch_question' '123e4567-e89b-12d3-a456-426614174000' %}">
            {% url 'fetch_question' '123e4567-e89b-12d3-a456-426614174000' %}
        </a>
    </p>
    <p><a href="{% url 'jb_save_answer' %}">{% url 'jb_save_answer' %}</a></p>
</div>
</body>
</html>