# Generated by Django 3.2.5 on 2021-07-24 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0016_auto_20210724_2250'),
    ]

    operations = [
        migrations.AddField(
            model_name='candidateassessment',
            name='evaluation_url',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='candidateassessment',
            name='note',
            field=models.TextField(blank=True, null=True),
        ),
    ]
