# Generated by Django 3.2.5 on 2021-07-25 10:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0018_auto_20210724_2332'),
    ]

    operations = [
        migrations.AddField(
            model_name='assessment',
            name='type',
            field=models.CharField(choices=[('mcq', 'MCQ Examination'), ('written', 'Written Examination'), ('viva', 'Viva/Oral Examination')], default='mcq', max_length=40),
        ),
        migrations.AlterField(
            model_name='candidateassessment',
            name='candidate_job',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='candidate_job', to='job_board.candidatejob'),
        ),
    ]
