# Generated by Django 3.2.5 on 2021-07-14 07:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0005_auto_20210702_1224'),
    ]

    operations = [
        migrations.AddField(
            model_name='candidate',
            name='email_otp',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AddField(
            model_name='candidate',
            name='email_verified_at',
            field=models.DateField(blank=True, null=True),
        ),
    ]
