# Generated by Django 3.2.4 on 2021-06-29 10:00

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0002_job_assessment'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='assessment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='job_board.assessment'),
        ),
    ]
