# Generated by Django 3.2.5 on 2021-07-28 16:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('job_board', '0030_candidateassessment_can_open_after'),
    ]

    operations = [
        migrations.RenameField(
            model_name='candidateassessment',
            old_name='can_open_after',
            new_name='can_start_after',
        ),
    ]
